==> azarashi-0.9.1-py3-none-any.whl: azarashi/qzss_dcr_lib/definition/qzss_dcr_jma_eew_forecast_region.py <==
from .qzss_dcr_definition import QzssDcrDefinition

qzss_dcr_jma_eew_forecast_region = QzssDcrDefinition(
    {
        1: "北海道道央",
        2: "北海道道南",
        3: "北海道道北",
        4: "北海道道東",
        5: "青森",
        6: "岩手",
        7: "宮城",
        8: "秋田",
        9: "山形",
        10: "福島",
        11: "茨城",
        12: "栃木",
        13: "群馬",
        14: "埼玉",
        15: "千葉",
        16: "東京",
        17: "伊豆諸島",
        18: "小笠原",
        19: "神奈川",
        20: "新潟",
        21: "富山",
        22: "石川",
        23: "福井",
        24: "山梨",
        25: "長野",
        26: "岐阜",
        27: "静岡",
        28: "愛知",
        29: "三重",
        30: "滋賀",
        31: "京都",
        32: "大阪",
        33: "兵庫",
        34: "奈良",
        35: "和歌山",
        36: "鳥取",
        37: "島根",
        38: "岡山",
        39: "広島",
        40: "山口",
        41: "徳島",
        42: "香川",
        43: "愛媛",
        44: "高知",
        45: "福岡",
        46: "佐賀",
        47: "長崎",
        48: "熊本",
        49: "大分",
        50: "宮崎",
        51: "鹿児島",
        52: "奄美(群島)",
        53: "沖縄本島",
        54: "大東島",
        55: "宮古島",
        56: "八重山",
        57: "北海道",
        58: "東北",
        59: "関東",
        60: "伊豆諸島",
        61: "小笠原",
        62: "北陸",
        63: "甲信",
        64: "東海",
        65: "近畿",
        66: "中国",
        67: "四国",
        68: "九州",
        69: "奄美(群島)",
        70: "沖縄",
        80: "その他の府県予報区および地方予報区_緊急地震速報(警報)",
        # "NN*": "府県予報区および地方予報区_緊急地震速報(警報)(地点：NN)",
    },
    undefined="府県予報区および地方予報区_緊急地震速報(警報)(地点：%d)"
)

==> azarashi-0.12.0-py3-none-any.whl: azarashi/qzss_dcr_lib/definition/qzss_dcr_jma_eew_forecast_region.py <==
from .qzss_dcr_definition import QzssDcrDefinition

qzss_dcr_jma_eew_forecast_region = QzssDcrDefinition(
    {
        1: "北海道道央",
        2: "北海道道南",
        3: "北海道道北",
        4: "北海道道東",
        5: "青森",
        6: "岩手",
        7: "宮城",
        8: "秋田",
        9: "山形",
        10: "福島",
        11: "茨城",
        12: "栃木",
        13: "群馬",
        14: "埼玉",
        15: "千葉",
        16: "東京",
        17: "伊豆諸島",
        18: "小笠原",
        19: "神奈川",
        20: "新潟",
        21: "富山",
        22: "石川",
        23: "福井",
        24: "山梨",
        25: "長野",
        26: "岐阜",
        27: "静岡",
        28: "愛知",
        29: "三重",
        30: "滋賀",
        31: "京都",
        32: "大阪",
        33: "兵庫",
        34: "奈良",
        35: "和歌山",
        36: "鳥取",
        37: "島根",
        38: "岡山",
        39: "広島",
        40: "山口",
        41: "徳島",
        42: "香川",
        43: "愛媛",
        44: "高知",
        45: "福岡",
        46: "佐賀",
        47: "長崎",
        48: "熊本",
        49: "大分",
        50: "宮崎",
        51: "鹿児島",
        52: "奄美(群島)",
        53: "沖縄本島",
        54: "大東島",
        55: "宮古島",
        56: "八重山",
        57: "北海道",
        58: "東北",
        59: "関東",
        60: "伊豆諸島",
        61: "小笠原",
        62: "北陸",
        63: "甲信",
        64: "東海",
        65: "近畿",
        66: "中国",
        67: "四国",
        68: "九州",
        69: "奄美(群島)",
        70: "沖縄",
        80: "その他の府県予報区および地方予報区",
        # "NN*": "府県予報区および地方予報区(コード：NN)",
    },
    undefined="府県予報区および地方予報区(コード番号：%d)"
)
